@@ -15,8 +15,8 @@ class CDlgSetup : public QDialog, private Ui::IDlgSetup
             virtual ~CDlgSetup();
 	
 	private:
-	
-	private slots:
+            void listTheme();
+        private slots:
 	    void slotCallSetup();
 	    void slotMP3Setup();
             void slotSmsSetup();
@@ -24,6 +24,10 @@ class CDlgSetup : public QDialog, private Ui::IDlgSetup
 	    void slotMafwActivate(int status);
 	    void slotRTComActivate(int status);
             void slotSmsActivate(int status);
+        private slots:
+            void slotThemeChanged(int index);
+        signals:
+            void newTheme(QString theme);
 
 };
 #endif
