@@ -1,3 +1,4 @@
+
 #ifndef CDLGSMS_H
 #define CDLGSMS_H
 
@@ -5,13 +6,16 @@
 #include <QWidget>
 #include <ui_IDlgSms.h>
 
+
 class CDlgSms : public QDialog, private Ui::IDlgSms
 {
     Q_OBJECT;
+        public:
+            CDlgSms(QWidget *parent);
+            virtual ~CDlgSms();
+        private:
 
-public:
-    CDlgSms(QWidget *parent = 0);
-    virtual ~CDlgSms();
+        private slots:
 
 };
 
