@@ -43,7 +43,7 @@ bool CFMRadio::sendAction(QString action, uint value)
     list.append(QVariant::fromValue(QDBusVariant(value) ) );
     message.setArguments(list);
     QDBusReply<QDBusVariant> reply = QDBusConnection::systemBus().call(message);
-    qDebug() << "message=" << reply.error().message();
+    //qDebug() << "message=" << reply.error().message();
     return true;
 }
 
