@@ -18,11 +18,15 @@ public:
     bool setFrequency(int freq);
     double getFrequency();
     double getStep();
-
+    double getMax();
+    double getMin();
+    bool setFreqUp();
+    bool setFreqDown();
 
 private:
     static CFMRadio * m_self;
     bool sendAction(QString action, QString value);
+    bool sendAction(QString action, uint value);
     QVariant getProperties(QString properties);
 
 signals:
