@@ -37,8 +37,8 @@ CMafwMeta::CMafwMeta(QObject * parent)
     timeout = cfg.value("display/mafw/timeout", timeout).toInt();
     state = cfg.value("main/mafw", state).toBool();
     // connect plug
-    setConnect(state);
     song.append( format);
+    connect = false;
 }
 
 
@@ -76,15 +76,19 @@ void CMafwMeta::setEnable(bool value)
     if (value) {
     	bConnect = QDBusConnection::sessionBus().connect( 0, MAFW_METADATA_PATH, MAFW_METADATA_IF,  "metadata_changed", this, SLOT(slotMetadataChanged(QString,uint,QDBusVariant)));
     	bConnect =  QDBusConnection::sessionBus().connect( 0, MAFW_METADATA_PATH, MAFW_METADATA_IF,  "state_changed", this, SLOT(slotPlayerState(int)));
-	state = bConnect;
     } else {
     	QDBusConnection::sessionBus().disconnect( 0, MAFW_METADATA_PATH, MAFW_METADATA_IF,  "metadata_changed", this, SLOT(slotMetadataChanged(QString,uint,QDBusVariant)));
     	QDBusConnection::sessionBus().disconnect( 0, MAFW_METADATA_PATH, MAFW_METADATA_IF,  "state_changed", this, SLOT(slotPlayerState(int)));
-	state = value;
-    }    
+    }
+    state = value;
 }
 
 bool CMafwMeta::getEnable()
+{
+    return state && connect;
+}
+
+bool CMafwMeta::getState()
 {
     return state;
 }
@@ -119,7 +123,8 @@ void CMafwMeta::setConnect(int value)
 	// If activate check before the internal plug state
 	setEnable(state);
     } else {
-    	QDBusConnection::sessionBus().disconnect( 0, MAFW_METADATA_PATH, MAFW_METADATA_IF,  "metadata_changed", this, SLOT(slotMetadataChanged(QString,uint,QDBusVariant)));
-    	QDBusConnection::sessionBus().disconnect( 0, MAFW_METADATA_PATH, MAFW_METADATA_IF,  "state_changed", this, SLOT(slotPlayerState(int)));
-    }    
+        QDBusConnection::sessionBus().disconnect( 0, MAFW_METADATA_PATH, MAFW_METADATA_IF,  "metadata_changed", this, SLOT(slotMetadataChanged(QString,uint,QDBusVariant)));
+        QDBusConnection::sessionBus().disconnect( 0, MAFW_METADATA_PATH, MAFW_METADATA_IF,  "state_changed", this, SLOT(slotPlayerState(int)));
+    }
+    connect = value;
 }
