@@ -3,6 +3,15 @@
 
 #include "IRdsText.h"
 #include <QtDBus>
+#include <QMessageManager>
+
+
+QTM_BEGIN_NAMESPACE
+class QMessag;
+class QGeoPositionInfoSource;
+QTM_END_NAMESPACE
+
+QTM_USE_NAMESPACE
 
 class CSms : public IRdsText
 {
@@ -28,7 +37,7 @@ public:
 
 signals:
     /// emitted when ever the new text is changed
-    void sigChanged(QString,int);
+    //void sigChanged(QString,int);
 
 private:
     // Send text to writer
@@ -46,12 +55,11 @@ private:
     bool state;
     // Tx connect state
     bool bConnect;
+    QMessageManager *messageManager;
+    QMessageManager::NotificationFilterIdSet m_notifFilterSet;
 
 private slots:
-    void slotNotify(QList<QVariant> var);
-    void slotComingChanged(QDBusObjectPath objPath, QString channel,uint ukn,uint num,bool act);
-    void slotTextReceived(uint ukn,uint time,uint chan, uint ukn2, uint ukn3,QString text);
-
+    void slotMessageAdded(QMessageId,QMessageManager::NotificationFilterIdSet);
 };
 
 #endif // CSMS_H
